@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+from valid8r.core import schema
 from valid8r.core.parsers import (
     EmailAddress,
     UrlParts,
@@ -13,10 +14,12 @@ from valid8r.core.parsers import (
     parse_ipv6,
     parse_url,
 )
+from valid8r.core.type_adapters import from_type
 
 __all__ = [
     'EmailAddress',
     'UrlParts',
+    'from_type',
     'parse_cidr',
     'parse_email',
     'parse_ip',
@@ -25,4 +28,6 @@ __all__ = [
     'parse_ipv6',
     # URL/Email helpers
     'parse_url',
+    # Schema validation
+    'schema',
 ]
